bodhi-monitor-composes — bodhi 3.1.0 documentation

# bodhi-monitor-composes

## Synopsis

`bodhi-monitor-composes`

## Description

`bodhi-monitor-composes` prints a human-readable report about the running Composes.

## Options

`--help`

> Display help text.

`--version`

> Report the Bodhi version and exit.

## Help

If you find bugs in bodhi (or in the man page), please feel free to file a bug report or a pull request:

> https://github.com/fedora-infra/bodhi

Bodhi’s documentation is available online: https://bodhi.fedoraproject.org/docs